@@ -202,8 +202,11 @@ class AMQPData(GeneralData):
                 rprint(":::>")
                 bprint(body)
                 rprint(":::>")
-                strb = str(body, 'utf-8').replace("'", "\"")
-                new_json = json.loads(strb)
+                strb = str(body, 'utf-8')
+                char = '}'
+                positions = [i for i, v in enumerate(strb) if v==char]
+                dic = strb[:positions[-1]+1]
+                new_json = json.loads(dic)
             except Exception as e:
                 self.logger.exception(
                     "Error on consume_exchange_mq convert json %s, error %e" %
